@@ -12,9 +12,9 @@ UI::Various - graphical/non-graphical user interface without external programs
 
 =head1 ABSTRACT
 
-B<Currently this module is WORK IN PROGRESS and of limited usage!> It is
-updated and uploaded often to get the results of the tests on the various
-different CPAN test platforms.
+B<This module is still WORK IN PROGRESS, but already usable with some
+restrictions.> Currently it provides basic functionality only (no dialogues,
+no frills).
 
 Did you ever need to decide if a graphical or text based user interface is
 best for your Perl application?  A GUI may be easier to use, but will not
@@ -121,7 +121,7 @@ use warnings 'once';
 
 use Carp;			# may only be used in import!
 
-our $VERSION = "0.18";
+our $VERSION = "0.19";
 
 BEGIN  {  require UI::Various::core;  }
 
